netapp_ontap.models.volume_autosize API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_autosize`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeAutosizeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeAutosize object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `grow_threshold GET POST PATCH`

    Used space threshold size, in percentage, for the automatic growth of the volume. When the amount of used space in the volume becomes greater than this threhold, the volume automatically grows unless it has reached the maximum size. The volume grows when 'space.used' is greater than this percent of 'space.size'. The 'grow_threshold' size cannot be less than or equal to the 'shrink_threshold' size..

  `maximum GET POST PATCH`

    Maximum size in bytes up to which a volume grows automatically. This size cannot be less than the current volume size, or less than or equal to the minimum size of volume.

  `minimum GET POST PATCH`

    Minimum size in bytes up to which the volume shrinks automatically. This size cannot be greater than or equal to the maximum size of volume.

  `mode GET POST PATCH`

    Autosize mode for the volume.
    grow ‐ Volume automatically grows when the amount of used space is above the 'grow_threshold' value.
    grow_shrink ‐ Volume grows or shrinks in response to the amount of space used.
    off ‐ Autosizing of the volume is disabled.

    Valid choices:

    - grow
    - grow_shrink
    - off
  `shrink_threshold GET POST PATCH`

    Used space threshold size, in percentage, for the automatic shrinkage of the volume. When the amount of used space in the volume drops below this threshold, the volume automatically shrinks unless it has reached the minimum size. The volume shrinks when the 'space.used' is less than the 'shrink_threshold' percent of 'space.size'. The 'shrink_threshold' size cannot be greater than or equal to the 'grow_threshold' size.